@@ -1,10 +1,10 @@
-#!/usr/bin/python2.7
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 #
 # Univention Management Console
 #  module: system setup
 #
-# Copyright 2011-2021 Univention GmbH
+# Copyright 2011-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -31,31 +31,34 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-import stringprep
-import threading
-import traceback
-import time
-import re
-import os
 import copy
-import subprocess
 import json
 import locale as _locale
-import lxml.etree
-import psutil
+import os
+import re
+import stringprep
+import subprocess
+import threading
+import time
+import traceback
 
+import lxml.etree
 import notifier
 import notifier.threads
+import psutil
 
-from univention.management.console.modules import Base
-from univention.management.console.log import MODULE
-from univention.management.console.modules.mixins import ProgressMixin
-from univention.management.console.modules.sanitizers import PatternSanitizer, StringSanitizer, IntegerSanitizer
-from univention.management.console.modules.decorators import sanitize, simple_response
-from univention.lib.i18n import Translation, Locale
 import univention.config_registry
-from univention.lib.admember import lookup_adds_dc, connectionFailed, failedADConnect
-from univention.management.console.modules import UMC_Error
+from univention.lib.admember import connectionFailed, failedADConnect, lookup_adds_dc
+from univention.lib.i18n import Locale, Translation
+from univention.management.console.log import MODULE
+from univention.management.console.modules import Base, UMC_Error
+from univention.management.console.modules.decorators import sanitize, simple_response
+from univention.management.console.modules.mixins import ProgressMixin
+from univention.management.console.modules.sanitizers import (
+	IntegerSanitizer,
+	PatternSanitizer,
+	StringSanitizer,
+)
 
 # FIXME: this triggers imports from univention-lib during build time test execution.
 # This in effect imports univention-ldap which is not an explicit dependency for
@@ -64,16 +67,19 @@ from univention.management.console.modules import UMC_Error
 # univention-lib package.
 try:
 	from univention.appcenter.app_cache import AppCache
-except ImportError as e:
-	MODULE.warn('Ignoring import error: %s' % e)
+except ImportError as exc:
+	MODULE.warn('Ignoring import error: %s' % (exc,))
 
 
-from univention.management.console.modules.setup import network
-from univention.management.console.modules.setup import util
+from univention.management.console.modules.setup import network, util
 from univention.management.console.modules.setup.checks.ldap import check_if_uid_is_available
-from univention.management.console.modules.setup.checks.repositories import get_unreachable_repository_servers
+from univention.management.console.modules.setup.checks.repositories import (
+	get_unreachable_repository_servers,
+)
 from univention.management.console.modules.setup.checks.univention_join import (
-	receive_domaincontroller_master_information, set_role_and_check_if_join_will_work, check_for_school_domain,
+	check_for_school_domain,
+	receive_domaincontroller_master_information,
+	set_role_and_check_if_join_will_work,
 )
 
 ucr = univention.config_registry.ConfigRegistry()
@@ -213,7 +219,7 @@ class Instance(Base, ProgressMixin):
 				restart = False
 				if not run_hooks:
 					MODULE.info('Check whether ip addresses have been changed')
-					for ikey, ival in values.iteritems():
+					for ikey, ival in values.items():
 						if RE_IPV4.match(ikey) or RE_IPV6_DEFAULT.match(ikey) or RE_SSL.match(ikey):
 							restart = True
 							break
@@ -371,7 +377,7 @@ class Instance(Base, ProgressMixin):
 
 		# mix original and new values
 		allValues = copy.copy(values)
-		for ikey, ival in orgValues.iteritems():
+		for ikey, ival in orgValues.items():
 			if ikey not in allValues:
 				allValues[ikey] = ival
 
@@ -451,7 +457,7 @@ class Instance(Base, ProgressMixin):
 
 		for ikey in ('ssl/country', 'ssl/state', 'ssl/locality', 'ssl/organization', 'ssl/organizationalunit', 'ssl/email', 'ssl/common'):
 			for table in (stringprep.in_table_c21_c22, stringprep.in_table_a1, stringprep.in_table_c8, stringprep.in_table_c3, stringprep.in_table_c4, stringprep.in_table_c5, lambda c: c == u'\ufffd'):
-				_check(ikey, lambda x: not any(map(table, unicode(x))), _('The value for %s contains invalid characters.') % (labels[ikey],))
+				_check(ikey, lambda x: not any(map(table, x)), _('The value for %s contains invalid characters.') % (labels[ikey],))
 
 		_check('ssl/country', lambda x: len(x) == 2, _('Country must be a country code consisting of 2 characters.'))
 		for ikey in ['ssl/email', 'email_address']:
@@ -471,7 +477,7 @@ class Instance(Base, ProgressMixin):
 		# check nameservers
 		for ikey, iname in [('nameserver[1-3]', _('Domain name server')), ('dns/forwarder[1-3]', _('External name server'))]:
 			reg = re.compile('^(%s)$' % ikey)
-			for jkey, jval in values.iteritems():
+			for jkey, jval in values.items():
 				if reg.match(jkey):
 					if not values.get(jkey):
 						# allow empty value
@@ -547,13 +553,13 @@ class Instance(Base, ProgressMixin):
 	def lang_timezones(self, request):
 		'''Return a list of all available time zones.'''
 		try:
-			file = open('/usr/share/univention-system-setup/locale/timezone')
+			fd = open('/usr/share/univention-system-setup/locale/timezone')
 		except EnvironmentError:
 			MODULE.error('Cannot find locale data for timezones in /usr/share/univention-system-setup/locale')
 			self.finished(request.id, None)
 			return
 
-		timezones = [i.strip('\n') for i in file if not i.startswith('#')]
+		timezones = [i.strip('\n') for i in fd if not i.startswith('#')]
 
 		self.finished(request.id, timezones)
 
@@ -617,7 +623,7 @@ class Instance(Base, ProgressMixin):
 			'id': icountry,
 			'label': self._get_localized_label(idata.get('label', {})),
 		}
-			for icountry, idata in country_data.iteritems()
+			for icountry, idata in country_data.items()
 			if idata.get('label')]
 
 		# add the value from ucr value to the list
@@ -705,7 +711,7 @@ class Instance(Base, ProgressMixin):
 		matches = []
 		for icity in city_data:
 			match = None
-			for jlabel in icity.get('label', {}).itervalues():
+			for jlabel in icity.get('label', {}).values():
 				label = jlabel.decode(self.locale.codeset).lower()
 				if pattern in label:
 					# matching score is the overlap if the search pattern and the matched text
@@ -727,7 +733,7 @@ class Instance(Base, ProgressMixin):
 
 		# add additional score w.r.t. the population size of the city
 		# such that the largest city gains additional 0.4 on top
-		max_population = max([imatch['population'] for imatch in matches])
+		max_population = max(imatch['population'] for imatch in matches)
 		weighted_inv_max_population = 0.6 / float(max_population)
 		for imatch in matches:
 			imatch['final_score'] = imatch['match_score'] + weighted_inv_max_population * imatch['population']
