@@ -43,6 +43,6 @@ class PhaseRestartAllInterfaces(Phase):
 			return False
 		if iface.ipv4_address():
 			return True
-		if any((iface.ipv6_address(name) for name in iface.ipv6_names)):
+		if any(iface.ipv6_address(name) for name in iface.ipv6_names):
 			return True
 		return False
